@@ -112,7 +112,7 @@ COMMANDS = {
     "ipv6-restore": "/usr/bin/ip6tables-restore",
     "eb":           "/bin/false",
     "eb-restore":   "/bin/false",
-    "ipset":        "/bin/false",
+    "ipset":        "/usr/bin/ipset",
     "modprobe":     "/usr/bin/modprobe",
     "rmmod":        "/usr/bin/rmmod",
 }
