@@ -277,7 +277,7 @@ class IPSet(IO_Object):
                 raise FirewallError(errors.INVALID_IPSET,
                                     "ipset type '%s' not usable" % ipset_type)
 
-    def _check_config(self, config, item):
+    def _check_config(self, config, item, all_config):
         if item == "type":
             if config not in IPSET_TYPES:
                 raise FirewallError(errors.INVALID_TYPE,
@@ -390,9 +390,11 @@ def ipset_reader(filename, path):
     parser = sax.make_parser()
     parser.setContentHandler(handler)
     name = "%s/%s" % (path, filename)
-    with open(name, "r") as f:
+    with open(name, "rb") as f:
+        source = sax.InputSource(None)
+        source.setByteStream(f)
         try:
-            parser.parse(f)
+            parser.parse(source)
         except sax.SAXParseException as msg:
             raise FirewallError(errors.INVALID_IPSET,
                                 "not a valid ipset file: %s" % \
